@@ -4,10 +4,8 @@ Created on Wed Mar 30 11:55:34 2016
 
 @author: Tobias Jachowski
 """
-import collections
 import numpy as np
 import matplotlib.pyplot as plt
-import os
 
 from . import signal as sn
 from .. import gui
@@ -128,8 +126,8 @@ class Evaluator(object):
 
         self.rfigure = None
 
-    def get_data(self, traces=None, samples=None, copy=False, resolution=0,
-                 moving_filter=None, filter_time=-1.0):
+    def get_data(self, traces=None, samples=None, moving_filter=None,
+                 filter_time=-1.0, copy=False, time=False, resolution=0):
         """
         Get data of `self.region` with a defined resolution and smoothed by
         a moving filter.
@@ -144,11 +142,6 @@ class Evaluator(object):
             you want to have a defined resolution, via the paramters
             `resolution` or the attribute `self.resolution`, do only use int or
             slice and do set the step value of the slice to None or 1.
-        copy: bool, optional
-            see parameters of method `pyoti.region.Region.get_data()`
-        resolution : int, optional
-            Set the resolution of the returned data. If `resolution` <= 0
-            (default), use `self.resolution` to set the resolution of the data.
         moving_filter : str, optional
             The moving filter to apply to the data. Can be one of 'mean' or
             'median'. Only applied, if `filter_time` != 0.0. Defaults to
@@ -158,6 +151,13 @@ class Evaluator(object):
             filter. If `filter_time` is < 0.0 (default), use
             `self.filter_time` as the window length. If `filter_time` == 0.0,
             do not smooth the data.
+        copy: bool, optional
+            see parameters of method `pyoti.region.Region.get_data()`
+        time : bool, optional
+            Add the time as the first trace.
+        resolution : int, optional
+            Set the resolution of the returned data. If `resolution` <= 0
+            (default), use `self.resolution` to set the resolution of the data.
 
         Returns
         -------
@@ -181,9 +181,9 @@ class Evaluator(object):
         # Convert samples into the scope of self.region.get_data()
         samples = self.decimate_and_limit(samples)
 
-        return self.region.get_data(traces=traces, samples=samples, copy=copy,
+        return self.region.get_data(traces=traces, samples=samples,
                                     moving_filter=moving_filter, window=window,
-                                    decimate=decimate)
+                                    decimate=decimate, copy=copy, time=time)
 
     def update(self):
         window = self.window_sf
@@ -255,6 +255,10 @@ class Evaluator(object):
         return sections
 
     def undecimate_and_limit(self, sections):
+        """
+        Convert the indices given with the resolution of `self.resolution_sf`
+        to indices given with the resolution of `self.resolution`.
+        """
         # undecimate the sections
         undecimate = self.decimate_sf / self.decimate
         max_stop = int(np.ceil(self.region.datapoints / self.decimate))
@@ -263,6 +267,10 @@ class Evaluator(object):
         return sections
 
     def decimate_and_limit(self, samples):
+        """
+        Convert the indices given with the resolution of `self.resolution`
+        to indices given with the resolution of `self.region.samplingrate`.
+        """
         if samples is None:
             return None
 
@@ -414,51 +422,3 @@ class Evaluator(object):
     @calibration.setter
     def calibration(self, calibration):
         self._calibration = calibration
-
-
-def save_figures(figures, directory=None, file_prefix=None, file_suffix=None,
-                 file_extension='.png', index_digits=3):
-    """
-    Save matplotlib figures in a given directory.
-
-    The filenames of the figures will be a concatenation of the `file_prefix`,
-    an index with `index_digits` digits, the `file_suffix` and the
-    `file_extension`.
-
-    Parameters
-    ----------
-    figures : Iterable of matplotlib figures or one figure
-        A list, array, generator or other Iterable type of matplotlib figures.
-        If figures is only one matplotlib figure, no index will be included in
-        the filename of the figure.
-    directory : str
-        The directory, the figures should be saved in. The directory will be
-        created, if it does not exist.
-    file_prefix : str, optional
-        A prefix every filename of the saved figures should include.
-    file_suffix : str, optional
-        A suffix every filename of the saved figures should include.
-    files_extension : str, optional
-        The file extension (and type) to be used to save the figures (default
-        '.png').
-    index_digits : int, optional
-        Digits to be used for the index in the filename of the figures.
-    """
-    directory = directory or os.path.join(".", "results")
-    file_prefix = file_prefix or ""
-    file_suffix = file_suffix or ""
-
-    # create results dir
-    if not os.path.exists(directory):
-        os.makedirs(directory)
-
-    # If only one figure, save it without an index
-    if not isinstance(figures, collections.Iterable):
-        filename = "%s%s%s" % (file_prefix, file_suffix, file_extension)
-        figures.savefig(os.path.join(directory, filename))
-
-    for idx, fig in enumerate(figures):
-        format_string = "".join(("%s%.", str(index_digits), "i%s%s"))
-        filename = format_string % (file_prefix, idx, file_suffix,
-                                    file_extension)
-        fig.savefig(os.path.join(directory, filename))
